@@ -1,9 +1,9 @@
-__version__ = "2.2.1"
-__version_vector__ = (2, 2, 1)
+__version__ = "2.3.0"
+__version_vector__ = (2, 3, 0)
 
 from . import config
 
-logger = config.logger
+logger = config.get_logger(__name__)
 
 # Flatten namespace by importing contents of all modules of pymaid
 from .fetch import *
